@@ -25,3 +25,21 @@ broom::glance
 #' @export
 #' @importFrom broom augment
 broom::augment
+
+# gtsummary --------------------------------------------------------------------
+#' @export
+#' @importFrom gtsummary add_n
+gtsummary::add_n
+
+#' @export
+#' @importFrom gtsummary add_nevent
+gtsummary::add_nevent
+
+#' @export
+#' @importFrom gtsummary add_p
+gtsummary::add_p
+
+#' @export
+#' @importFrom gtsummary inline_text
+gtsummary::inline_text
+
