@@ -1,7 +1,5 @@
 #' Tabular Summary of Cumulative Incidence
 #'
-#' *This is experimental and breaking changes may be made in a future release.*
-#'
 #' @param x a 'tidycuminc' object created with `cuminc()`
 #' @param outcomes character vector of outcomes to include. Default
 #' is to include the first outcome.
@@ -114,17 +112,17 @@ tbl_cuminc.tidycuminc <- function(x,
       dplyr::full_join(
         tidy(x, times = 0) %>%
           select(any_of(c("outcome", "strata")),
-                 n = .data$n.risk),
+                 n = "n.risk"),
         tidy(x, times = max(x$tidy$time) + 1) %>%
           select(any_of(c("outcome", "strata")),
-                 n.event = .data$cum.event)
+                 n.event = "cum.event")
       )
     ) %>%
     dplyr::group_by(.data$outcome) %>%
     mutate(
       N = sum(.data$n),
       N.event = sum(.data$n.event),
-      .before = .data$n
+      .before = dplyr::all_of("n")
     ) %>%
     dplyr::ungroup()
 
@@ -134,8 +132,8 @@ tbl_cuminc.tidycuminc <- function(x,
     select(dplyr::any_of(c("outcome", "strata", "column_name", "statistic"))) %>%
     tidyr::pivot_wider(
       id_cols = dplyr::any_of(c("outcome", "strata")),
-      names_from = .data$column_name,
-      values_from = .data$statistic
+      names_from = "column_name",
+      values_from = "statistic"
     ) %>%
     mutate(row_type = "level") %>%
     purrr::when(
@@ -161,7 +159,7 @@ tbl_cuminc.tidycuminc <- function(x,
     {suppressMessages(
       dplyr::left_join(
         .,
-        select(df_n, .data$outcome, dplyr::starts_with("N", ignore.case = FALSE)) %>% dplyr::distinct()
+        select(df_n, dplyr::all_of("outcome"), dplyr::starts_with("N", ignore.case = FALSE)) %>% dplyr::distinct()
       )
     )} %>%
     {suppressMessages(
@@ -227,7 +225,6 @@ tbl_cuminc <- function(x, ...) {
 #' Additional Functions for `tbl_cuminc()`
 #'
 #' @description
-#' *This is experimental and breaking changes may be made in a future release.*
 #'
 #' - `add_p()` Add column with p-value comparing incidence across stratum
 #' - `add_n()` Add column with the total N, or N within stratum
@@ -304,7 +301,7 @@ add_p.tbl_cuminc <- function(x, pvalue_fun = gtsummary::style_pvalue, ...) {
       names_pattern = "(.*)_(.*)"
     ) %>%
     mutate(row_type = "label") %>%
-    select(-.data$outcome_id)
+    select(-dplyr::all_of("outcome_id"))
 
   # merge p-values into tbl
   x %>%
@@ -355,7 +352,7 @@ add_n.tbl_cuminc <- function(x, location = NULL, ...) {
               .data$row_type == "level" & "level" %in% .env$location,
               .data$n,
               .data$stat_n),
-          .after = .data$label
+          .after = dplyr::all_of("label")
         )
     ) %>%
     gtsummary::modify_table_styling(
@@ -387,7 +384,7 @@ add_nevent.tbl_cuminc <- function(x, location = NULL, ...) {
               .data$row_type == "level" & "level" %in% .env$location,
               .data$n.event,
               .data$stat_nevent),
-          .after = .data$label
+          .after = dplyr::all_of("label")
         )
     ) %>%
     gtsummary::modify_table_styling(
