@@ -12,6 +12,15 @@ test_that("crr() works", {
     NA
   )
 
+  expect_equal(
+    crr(Surv(ttdeath, death_cr) ~ age + trt,
+        data = trial %>% dplyr::mutate(trt = factor(trt, levels = paste("Drug", c("A", "B", "C"))))) %>%
+      utils::modifyList(val = list(data = NULL, blueprint = NULL, xlevels = NULL)),
+    crr(Surv(ttdeath, death_cr) ~ age + trt,
+        data = trial %>% dplyr::mutate(trt = factor(trt))) %>%
+      utils::modifyList(val = list(data = NULL, blueprint = NULL, xlevels = NULL))
+  )
+
   expect_equal(
     tidy(crr1, conf.int = TRUE) %>%
       select(all_of(names(.) %>% sort())),
